@@ -5,6 +5,7 @@ _nn_dir=os.path.dirname(os.path.realpath(__file__))
 #
 # CONSTANTS
 #
+TFBOX='tfbox'
 CONFIGS_DIR=f'{_nn_dir}/configs'
 YAML_RGX='.(yaml|yml)$'
 JSON_RGX='.json$'
@@ -14,7 +15,12 @@ JSON_RGX='.json$'
 #
 # I/0
 #
-def config(cfig,key_path=None,is_file_path=False,**kwargs):
+def config(
+        cfig,
+        key_path=None,
+        is_file_path=False,
+        cfig_dir=TFBOX,
+        **kwargs):
     if isinstance(cfig,str):
         if not is_file_path:
             parts=cfig.split('.')
@@ -22,11 +28,12 @@ def config(cfig,key_path=None,is_file_path=False,**kwargs):
             key_path=key_path or parts[1:] or name
             if isinstance(key_path,str):
                 key_path=[key_path]
-            cfig=f'{CONFIGS_DIR}/{name}.yaml'
-        if re.search(JSON_RGX,cfig):
-            cfig=h.read_json(cfig)
-        else:
-            cfig=h.read_yaml(cfig)
+            cfig=f'{name}.yaml'
+            if cfig_dir in [TFBOX,None,True]:
+                cfig_dir=CONFIGS_DIR
+            if cfig_dir:
+                cfig=f'{cfig_dir}/{name}.yaml'
+        cfig=h.read_yaml(cfig)
     if key_path:
         for k in key_path: cfig=cfig[k]
     cfig.update(kwargs)
